@@ -195,9 +195,12 @@ typedef enum _MetaKeyBindingAction
   META_KEYBINDING_ACTION_CYCLE_WINDOWS_BACKWARD,
   META_KEYBINDING_ACTION_CYCLE_PANELS,
   META_KEYBINDING_ACTION_CYCLE_PANELS_BACKWARD,
+  META_KEYBINDING_ACTION_TAB_POPUP_SELECT,
+  META_KEYBINDING_ACTION_TAB_POPUP_CANCEL,
   META_KEYBINDING_ACTION_SHOW_DESKTOP,
   META_KEYBINDING_ACTION_PANEL_MAIN_MENU,
   META_KEYBINDING_ACTION_PANEL_RUN_DIALOG,
+  META_KEYBINDING_ACTION_TOGGLE_RECORDING,
   META_KEYBINDING_ACTION_COMMAND_1,
   META_KEYBINDING_ACTION_COMMAND_2,
   META_KEYBINDING_ACTION_COMMAND_3,
@@ -209,7 +212,75 @@ typedef enum _MetaKeyBindingAction
   META_KEYBINDING_ACTION_COMMAND_9,
   META_KEYBINDING_ACTION_COMMAND_10,
   META_KEYBINDING_ACTION_COMMAND_11,
-  META_KEYBINDING_ACTION_COMMAND_12
+  META_KEYBINDING_ACTION_COMMAND_12,
+  META_KEYBINDING_ACTION_COMMAND_13,
+  META_KEYBINDING_ACTION_COMMAND_14,
+  META_KEYBINDING_ACTION_COMMAND_15,
+  META_KEYBINDING_ACTION_COMMAND_16,
+  META_KEYBINDING_ACTION_COMMAND_17,
+  META_KEYBINDING_ACTION_COMMAND_18,
+  META_KEYBINDING_ACTION_COMMAND_19,
+  META_KEYBINDING_ACTION_COMMAND_20,
+  META_KEYBINDING_ACTION_COMMAND_21,
+  META_KEYBINDING_ACTION_COMMAND_22,
+  META_KEYBINDING_ACTION_COMMAND_23,
+  META_KEYBINDING_ACTION_COMMAND_24,
+  META_KEYBINDING_ACTION_COMMAND_25,
+  META_KEYBINDING_ACTION_COMMAND_26,
+  META_KEYBINDING_ACTION_COMMAND_27,
+  META_KEYBINDING_ACTION_COMMAND_28,
+  META_KEYBINDING_ACTION_COMMAND_29,
+  META_KEYBINDING_ACTION_COMMAND_30,
+  META_KEYBINDING_ACTION_COMMAND_31,
+  META_KEYBINDING_ACTION_COMMAND_32,
+  META_KEYBINDING_ACTION_COMMAND_SCREENSHOT,
+  META_KEYBINDING_ACTION_COMMAND_WINDOW_SCREENSHOT,
+  META_KEYBINDING_ACTION_COMMAND_TERMINAL,
+  META_KEYBINDING_ACTION_SET_SPEW_MARK,
+  META_KEYBINDING_ACTION_ACTIVATE_WINDOW_MENU,
+  META_KEYBINDING_ACTION_TOGGLE_FULLSCREEN,
+  META_KEYBINDING_ACTION_TOGGLE_MAXIMIZED,
+  META_KEYBINDING_ACTION_TOGGLE_ABOVE,
+  META_KEYBINDING_ACTION_MAXIMIZE,
+  META_KEYBINDING_ACTION_UNMAXIMIZE,
+  META_KEYBINDING_ACTION_TOGGLE_SHADED,
+  META_KEYBINDING_ACTION_MINIMIZE,
+  META_KEYBINDING_ACTION_CLOSE,
+  META_KEYBINDING_ACTION_BEGIN_MOVE,
+  META_KEYBINDING_ACTION_BEGIN_RESIZE,
+  META_KEYBINDING_ACTION_TOGGLE_ON_ALL_WORKSPACES,
+  META_KEYBINDING_ACTION_MOVE_TO_WORKSPACE_1,
+  META_KEYBINDING_ACTION_MOVE_TO_WORKSPACE_2,
+  META_KEYBINDING_ACTION_MOVE_TO_WORKSPACE_3,
+  META_KEYBINDING_ACTION_MOVE_TO_WORKSPACE_4,
+  META_KEYBINDING_ACTION_MOVE_TO_WORKSPACE_5,
+  META_KEYBINDING_ACTION_MOVE_TO_WORKSPACE_6,
+  META_KEYBINDING_ACTION_MOVE_TO_WORKSPACE_7,
+  META_KEYBINDING_ACTION_MOVE_TO_WORKSPACE_8,
+  META_KEYBINDING_ACTION_MOVE_TO_WORKSPACE_9,
+  META_KEYBINDING_ACTION_MOVE_TO_WORKSPACE_10,
+  META_KEYBINDING_ACTION_MOVE_TO_WORKSPACE_11,
+  META_KEYBINDING_ACTION_MOVE_TO_WORKSPACE_12,
+  META_KEYBINDING_ACTION_MOVE_TO_WORKSPACE_LEFT,
+  META_KEYBINDING_ACTION_MOVE_TO_WORKSPACE_RIGHT,
+  META_KEYBINDING_ACTION_MOVE_TO_WORKSPACE_UP,
+  META_KEYBINDING_ACTION_MOVE_TO_WORKSPACE_DOWN,
+  META_KEYBINDING_ACTION_RAISE_OR_LOWER,
+  META_KEYBINDING_ACTION_RAISE,
+  META_KEYBINDING_ACTION_LOWER,
+  META_KEYBINDING_ACTION_MAXIMIZE_VERTICALLY,
+  META_KEYBINDING_ACTION_MAXIMIZE_HORIZONTALLY,
+  META_KEYBINDING_ACTION_MOVE_TO_CORNER_NW,
+  META_KEYBINDING_ACTION_MOVE_TO_CORNER_NE,
+  META_KEYBINDING_ACTION_MOVE_TO_CORNER_SW,
+  META_KEYBINDING_ACTION_MOVE_TO_CORNER_SE,
+  META_KEYBINDING_ACTION_MOVE_TO_SIDE_N,
+  META_KEYBINDING_ACTION_MOVE_TO_SIDE_S,
+  META_KEYBINDING_ACTION_MOVE_TO_SIDE_E,
+  META_KEYBINDING_ACTION_MOVE_TO_SIDE_W,
+  META_KEYBINDING_ACTION_MOVE_TO_CENTER,
+
+  META_KEYBINDING_ACTION_LAST
 } MetaKeyBindingAction;
 
 typedef struct
